package com.chaosserver.bilbo.data;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

import java.io.UnsupportedEncodingException;

/**
 * A Sax helper customized to read in the Xml representation
 * of a Directory object.
 *
 * @author Jordan Reed
 * @version 1.0
 * @since Bilbo 1.0
 */
public class DirectoryHandler extends DefaultHandler {
	/** Holds the directory currently being read in. */
	protected Directory directory;

	/** Holds the FilenameMapping currently being read in. */
	protected FilenameMapping filenameMapping;

	/** Holds the Name currently being read in. */
	protected Name name;

	/**
	 * Default constructor.
	 */
	public DirectoryHandler() {
	}

	/**
	 * Getter for the Directory object generated by this handler.
	 * <p>
	 * This method should be called after the handler has been used against
	 * an Xml document containing a directory.
	 * </p>
	 *
	 * @return the Directory read in by the handler
	 */
	protected Directory getDirectory() {
		return this.directory;
	}

	public void startElement(String uri, String localName, String qName, Attributes attributes)
			throws SAXException {


		super.startElement(uri, localName, qName, attributes);

		if(DataReaderWriter.DIRECTORY_TAG.equals(qName)) {
			directory = new Directory();
		}
		else if(DataReaderWriter.FILE_TAG.equals(qName)) {
			filenameMapping = new FilenameMapping();
		}
		else if(DataReaderWriter.NAME_TAG.equals(qName)) {
			name = new Name();

			for(int i=0; i<attributes.getLength(); i++) {
				if(DataReaderWriter.STYLE_ATT.equals(attributes.getQName(i))) {
					name.setStyle(attributes.getValue(i));
				}
			}
		}
	}

	public void characters(char[] ch, int start, int length) throws SAXException {
		super.characters(ch, start, length);

		if(name != null) {
			String currentValue = name.getValue();
			String newValue = new String(ch, start, length);
			try {
				newValue = new String(newValue.getBytes(), "UTF-8");
			}
			catch (UnsupportedEncodingException e) {
				// Eat it.
			}

			if(currentValue != null) {
				newValue = currentValue + newValue;
			}

			name.setValue(newValue);
		}
	}

	public void endElement(String uri, String localName, String qName) throws SAXException {
		super.endElement(uri, localName, qName);

		if(DataReaderWriter.DIRECTORY_TAG.equals(qName)) {
			// Done
		}
		else if(DataReaderWriter.FILE_TAG.equals(qName)) {
			directory.addFilenameMapping(filenameMapping);
			filenameMapping = null;
		}
		else if(DataReaderWriter.NAME_TAG.equals(qName)) {
			filenameMapping.addName(name);
			name = null;
		}

	}

}
