package com.chaosserver.bilbo.data;

import java.util.Collection;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * Holds a filename mapping.for a single file.
 * <p>
 * A mapping is just what a seems.
 * </p>
 *
 * @author Jordan Reed
 * @version 1.0
 * @since Bilbo 1.0
 */
public class FilenameMapping {
	/** Holds the collections of names for the FilenameMapping. */
	protected Collection names;

	/**
	 * Default constructor.
	 */
	public FilenameMapping() {
		names = new ArrayList();
	}

	/**
	 * Setter for the names property.
	 *
	 * @param names the value of names
	 */
	public void setNames(Collection names) {
		this.names = names;
	}

	/**
	 * Getter for the names property.
	 *
	 * @return the value of names
	 */
	public Collection getNames() {
		return this.names;
	}

	/**
	 * Adds a new name to the mapping.
	 *
	 * @param name the name to add
	 */
	public void addName(Name name) {
		// BUGBUG these needs to check for duplicate style
		names.add(name);
	}

	/**
	 * Finds the name mapping based on the style.
	 *
	 * @param style the style to return
	 * @throws NameNotFoundException if there is no mapping for the given style
	 */
	public Name findName(String style) throws NameNotFoundException {
		Iterator namesIterator = getNames().iterator();
		Name name = null;

		NAME_ITER: while(namesIterator.hasNext()) {
			name = (Name) namesIterator.next();

			if( name.getStyle().equals(style)) {
				break NAME_ITER;
			}

			name = null;
		}

		if(name == null) {
			throw new NameNotFoundException("Cound not find a mapping for style: style=" + style);
		}
		return name;
	}

	/**
	 * Finds the name mapping for the given style, with the given value.
	 *
	 * @param style the style to find
	 * @param value the value the name should have
	 *
	 * @throws NameNotFoundException if the name does not exist
	 */
	public Name findName(String style, String value) throws NameNotFoundException {
		Name name = findName(style);

		if( !name.getValue().equals(value) ) {
			throw new NameNotFoundException("Cound not find mapping.  Search criteria: "
				+ "style=" + style + ", value=" + value);
		}

		return name;
	}

	/**
	 * Generates a string version for debugging.
	 *
	 * @return a string version
	 */
	public String toString() {
		StringBuffer sb = new StringBuffer();

		sb.append(this.getClass().getName());
		sb.append(" [");
		sb.append("names=");
		sb.append(getNames());
		sb.append("]");

		return sb.toString();
	}
}