package com.chaosserver.bilbo.help;

import java.io.PrintStream;
import java.io.InputStream;
import java.io.IOException;

/**
 * Provides methods for processing of the help files.
 *
 * @author Jordan Reed
 * @version 1.0
 * @since Bilbo 2.0
 */
public class Helper {
	/**
	 * Default constructor.
	 */
	protected Helper() {}

	/**
	 * Prints the contents of the resource to the output stream.
	 *
	 * @param output the output stream to print the resource to
	 * @param resource the resource name
	 * @throws HelpResourceNotFoundException if the resource could not be found
	 * @throws HelpException levelized exception
	 */
	public static void printHelp(PrintStream output, String resource) throws HelpResourceNotFoundException, HelpException {
		ClassLoader classLoader = Helper.class.getClassLoader();
		InputStream inputStream = classLoader.getResourceAsStream(resource);

		if(inputStream == null) {
			throw new HelpResourceNotFoundException("Failed to find resource: " + resource);
		}

		try {
			byte[] b = new byte[2048];
			while(inputStream.read(b) > 0) {
				output.print((new String(b)).trim());
			}
			output.println("");
		}
		catch (IOException e) {
			throw new HelpException("Had some problems reading.", e);
		}
	}
}