package com.chaosserver.bilbo.task;

/**
 * A task that can be processed as part of Bilbo.
 * <p>
 * All Bilbo tasks must implement this interface.
 * </p>
 *
 * @author Jordan Reed
 * @version 1.0
 * @since Bilbo 2.0
 */
public interface Task {
	/**
	 * Setter for the settings object.
	 *
	 * @param settings the settings object
	 */
	public void setSettings(Settings settings);

	/**
	 * Parses the task specific argument string.
	 *
	 * @param argumentString the task specific argument string
	 * @throws BadTaskCommandArgumentsException if the argument string is invalid
	 */
	public void parseTaskArguments(String argumentString) throws BadTaskCommandArgumentsException;

	/**
	 * Executes the task.
	 *
	 * @throws TaskException if something goes wrong
	 */
	public void execute() throws TaskException;
}