package com.chaosserver.bilbo.textui;

import com.chaosserver.bilbo.data.DataReaderWriter;
import com.chaosserver.bilbo.data.Directory;
import com.chaosserver.bilbo.data.FilenameMapping;
import com.chaosserver.bilbo.data.FilenameMappingNotFoundException;
import com.chaosserver.bilbo.data.Name;
import com.chaosserver.bilbo.data.NameNotFoundException;
import com.chaosserver.bilbo.data.ReaderWriterException;
import com.chaosserver.bilbo.task.BadCommandArgumentsException;
import com.chaosserver.bilbo.task.Settings;
import com.chaosserver.bilbo.task.Task;
import com.chaosserver.bilbo.task.TaskFactory;
import com.chaosserver.bilbo.task.NoSuchTaskException;
import com.chaosserver.bilbo.help.Helper;
import com.chaosserver.bilbo.help.HelpException;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.StringWriter;
import java.net.URL;

/**
 * This is the main class to enter the text UI version of the program.
 *
 * @author Jordan Reed
 * @version 2.0
 * @since 1.0
 */
public class Main {
	/** Holds a reference to the settings objects. */
	protected static Settings settings;

	/**
	 * Default constructor.
	 */
	protected Main() {
	}

	/**
	 * Getter for Settings
	 *
	 * @return the settings object
	 */
	protected static Settings getSettings() {
		return Main.settings;
	}

	/**
	 * Setter for Settings
	 *
	 * @param settings the settings object
	 */
	protected static void setSettings(Settings settings) {
		Main.settings = settings;
	}

	/**
	 * The main method that is executed when the class is called.
	 *
	 * @param args The arguments.
	 * @throws Exception if something goes wrong
	 */
	public static void main(String args[]) throws Exception {
		try {
			Settings settings = new Settings();
			settings.parseArguments(args);
			setSettings(settings);

			TaskFactory taskFactory = TaskFactory.getInstance();
			Task task = taskFactory.createTask(settings.getTaskName(), settings);
			if(!settings.isHelp()) {
				task.parseTaskArguments(settings.getTaskArgs());
			}

			task.execute();
		}
		catch (NoSuchTaskException e) {
			System.out.println("No such command.");
			showUsage();
		}
		catch (BadCommandArgumentsException e) {
			showUsage();
		}
	}

	/**
	 * Prints out the main usage file.
	 *
	 * @throws HelpException if there is an error readin the usage.
	 */
	protected static void showUsage() throws HelpException {
		Helper.printHelp(System.out, "com/chaosserver/bilbo/help/usage.txt");
	}
}